summaryrefslogtreecommitdiff
path: root/t/spell2.sh
diff options
context:
space:
mode:
Diffstat (limited to 't/spell2.sh')
-rw-r--r--t/spell2.sh33
1 files changed, 28 insertions, 5 deletions
diff --git a/t/spell2.sh b/t/spell2.sh
index bf262f9f1..5e3ba65e3 100644
--- a/t/spell2.sh
+++ b/t/spell2.sh
@@ -14,18 +14,41 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-# Test to make sure misspellings in _SOURCES variables cause failure.
+# Test to make sure misspellings in _LDADD variable cause failure.
+required=cc
. test-init.sh
-echo AC_PROG_CC >> configure.ac
+cat >> configure.ac << 'END'
+AC_PROG_CC
+AC_OUTPUT
+END
cat > Makefile.am << 'END'
bin_PROGRAMS = zardoz
zardoz_SOURCES = x.c
-qardoz_LDADD = -ljoe
+qardoz_LDADD = -lm
END
+echo 'int main (void) { return 0; }' > x.c
+
$ACLOCAL
-AUTOMAKE_fails
-grep 'Makefile.am:3:.*qardoz' stderr
+$AUTOCONF
+$AUTOMAKE
+
+./configure
+
+run_make -E -e FAIL
+
+LC_ALL=C sed -e 's|^Makefile:[0-9][0-9]*: ||' \
+ -e 's|.*\.mk:[0-9][0-9]*: ||' \
+ -e '/^\*\*\*.*Automake-NG/d' stderr > got
+
+cat > exp << 'END'
+variable 'qardoz_LDADD' is defined but no program
+ or library has 'qardoz' as canonical name
+END
+
+diff exp got
+
+: